@@ -1,6 +1,4 @@
-"""
-    Predict Request API utilties
-"""
+"""Predict Request API utilties"""
 import requests
 import json
 
