@@ -10,10 +10,11 @@ from mldock.api.registry import \
     push_image_to_repository, pull_image_from_repository
 from mldock.config_managers.container import \
     MLDockConfigManager
+from mldock.terminal import ProgressLogger, pretty_build_logs
 
 click.disable_unicode_literals_warning = True
-logger=logging.getLogger('mldock')
-MLDOCK_CONFIG_NAME='mldock.json'
+logger = logging.getLogger('mldock')
+MLDOCK_CONFIG_NAME = 'mldock.json'
 
 def reset_terminal():
     # os.system("clear")
@@ -52,8 +53,9 @@ def registry():
     '--provider',
     help='Set the cloud provider',
     required=True,
-    type=click.Choice(['ecr', 'gcr', 'dockerhub'],
-    case_sensitive=False
+    type=click.Choice(
+        ['ecr', 'gcr', 'dockerhub'],
+        case_sensitive=False
     )
 )
 @click.option(
@@ -88,10 +90,16 @@ def push(obj, dir, region, build, provider, no_cache, stage, tag):
     )
     requirements_file_path = os.path.join(
         dir,
-        mldock_config.get("requirements.txt", "requirements.txt")
+        mldock_config.get("requirements", "requirements.txt")
     )
 
-    try:
+    # retrieve stages
+    with ProgressLogger(
+        group='Stages',
+        text='Retrieving Stages',
+        spinner='dots',
+        on_success='Stages Retrieved'
+    ) as spinner:
         stages = mldock_config.get("stages", None)
 
         if stage is not None:
@@ -99,22 +107,25 @@ def push(obj, dir, region, build, provider, no_cache, stage, tag):
 
         if tag is None:
             raise Exception("tag is not valid. Either choose a stage or set a tag manually")
-    except KeyError as exception:
-        logger.error("Stage not found. Either update stages in mldock config or manually set docker tag.")
-        raise
-    except Exception as exception:
-        logger.error(exception)
-        raise
-    try:
-        # login and authenticate
+
+    # athenticate and login docker client
+    with ProgressLogger(
+        group='Authentication',
+        text='Authenticating with {}'.format(provider),
+        spinner='dots'
+    ) as spinner:
         client, metadata = login_and_authenticate(provider=provider, region=region)
         image_repository = "{}/{}".format(metadata['repository'], image_name)
-        logger.info("\nLogin Complete! ヽ(´▽`)/\n")
 
-        if build:
-            logger.info("\nStarting build...\n")
-            # build image for cloud repository
-            docker_build(
+
+    if build:
+        # build image for cloud repository
+        with ProgressLogger(
+            group='Build',
+            text='Building',
+            spinner='dots'
+        ) as spinner:
+            logs = docker_build(
                 image_name=image_repository,
                 dockerfile_path=dockerfile_path,
                 module_path=module_path,
@@ -123,30 +134,29 @@ def push(obj, dir, region, build, provider, no_cache, stage, tag):
                 no_cache=no_cache,
                 docker_tag=tag
             )
-            logger.info("\nBuild Complete! ヽ(´▽`)/\n")
+            for line in logs:
 
-        # Push image to cloud repository
+                spinner.info(pretty_build_logs(line=line))
+
+                spinner.start()
+
+    # Push image to cloud repository
+    with ProgressLogger(group='Push', text='Pushing to {}'.format(image_repository), spinner='dots') as spinner:
         states = push_image_to_repository(
             image_repository=image_repository,
             auth_config = {'username': metadata['username'], 'password': metadata['password']},
             tag=tag
         )
-        reset_terminal()
-        logger.info(obj["logo"])
 
         for layer_id, metadata in states.items():
-            single_line = [
-                click.style(layer_id, bg='blue'),
-                click.style(metadata["message"], fg='white')
-            ]
-            single_line = " ".join(single_line)
-            click.echo(single_line, nl=True)
 
-        logger.info("\nPush Complete! ヽ(´▽`)/\n")
+            single_line = "{} {}".format(layer_id, metadata["message"])
 
-    except Exception as exception:
-        logger.error(exception)
-        raise
+            spinner.info(single_line)
+
+        reset_terminal()
+        logger.info(obj["logo"])
+        spinner.start()
 
 @click.command()
 @click.option(
@@ -189,6 +199,7 @@ def pull(obj, dir, region, provider, no_cache, stage, tag):
     mldock_manager = MLDockConfigManager(
         filepath=os.path.join(dir, MLDOCK_CONFIG_NAME)
     )
+
     # get mldock_module_dir name
     mldock_config = mldock_manager.get_config()
     image_name = mldock_config.get("image_name", None)
@@ -202,12 +213,14 @@ def pull(obj, dir, region, provider, no_cache, stage, tag):
         mldock_config.get("mldock_module_dir", "src"),
         container_dir
     )
-    requirements_file_path = os.path.join(
-        dir,
-        mldock_config.get("requirements.txt", "requirements.txt")
-    )
 
-    try:
+    # retrieve stages
+    with ProgressLogger(
+        group='Stages',
+        text='Retrieving Stages',
+        spinner='dots',
+        on_success='Stages Retrieved'
+    ) as spinner:
         stages = mldock_config.get("stages", None)
 
         if stage is not None:
@@ -215,40 +228,36 @@ def pull(obj, dir, region, provider, no_cache, stage, tag):
 
         if tag is None:
             raise Exception("tag is not valid. Either choose a stage or set a tag manually")
-    except KeyError as exception:
-        logger.error("Stage not found. Either update stages in mldock config or manually set docker tag.")
-        raise
-    except Exception as exception:
-        logger.error(exception)
-        raise
-    try:
-        # login and authenticate
+
+    # login and authenticate
+    with ProgressLogger(
+        group='Authentication',
+        text='Authenticating with {}'.format(provider),
+        spinner='dots'
+    ) as spinner:
         client, metadata = login_and_authenticate(provider=provider, region=region)
         image_repository = "{}/{}".format(metadata['repository'], image_name)
-        logger.info("\nLogin Complete! ヽ(´▽`)/\n")
 
-        # Push image to cloud repository
+    # Push image to cloud repository
+    with ProgressLogger(
+        group='Pull',
+        text='Pulling from {}'.format(image_repository),
+        spinner='dots'
+    ) as spinner:
         states = pull_image_from_repository(
             image_repository=image_repository,
             auth_config = {'username': metadata['username'], 'password': metadata['password']},
             tag=tag
         )
 
+        for layer_id, metadata in states.items():
+            single_line = "{} {}".format(layer_id, metadata["message"])
+
+            spinner.info(single_line)
+
         reset_terminal()
         logger.info(obj["logo"])
-
-        for layer_id, metadata in states.items():
-            single_line = [
-                click.style(layer_id, bg='blue'),
-                click.style(metadata["message"], fg='white')
-            ]
-            single_line = " ".join(single_line)
-            click.echo(single_line, nl=True)
-        logger.info("\nPull Complete! ヽ(´▽`)/\n")
-
-    except Exception as exception:
-        logger.error(exception)
-        raise
+        spinner.start()
 
 registry.add_command(push)
 registry.add_command(pull)
